<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>PluginItem</name>
    <message>
        <location filename="../pluginitem.cpp" line="89"/>
        <source>Remove from dock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickPluginItem</name>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Remove from dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Pin to dock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
